TFontBold class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
body(
BuildContext context) → TextStyle -
callout(
BuildContext context) → TextStyle -
caption1(
BuildContext context) → TextStyle -
caption2(
BuildContext context) → TextStyle -
footNote(
BuildContext context) → TextStyle -
headline(
BuildContext context) → TextStyle -
subHeadline(
BuildContext context) → TextStyle -
title1(
BuildContext context) → TextStyle -
title2(
BuildContext context) → TextStyle -
title3(
BuildContext context) → TextStyle -
titleLarge(
BuildContext context) → TextStyle