$AssetsSvgGen class

GENERATED CODE - DO NOT MODIFY BY HAND


FlutterGen


Constructors

$AssetsSvgGen()
const

Properties

chevronDown String
File path: assets/svg/chevron-down.svg
no setter
chevronLeft String
File path: assets/svg/chevron-left.svg
no setter
envelope String
File path: assets/svg/envelope.svg
no setter
eye String
File path: assets/svg/eye.svg
no setter
eyeSlash String
File path: assets/svg/eye-slash.svg
no setter
hashCode int
The hash code for this object.
no setterinherited
home String
File path: assets/svg/home.svg
no setter
informationCircle String
File path: assets/svg/information-circle.svg
no setter
magnifyingGlass String
File path: assets/svg/magnifying-glass.svg
no setter
nextCircle String
File path: assets/svg/next-circle.svg
no setter
previousCircle String
File path: assets/svg/previous-circle.svg
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values List<String>
List of all assets
no setter
xMark String
File path: assets/svg/x-mark.svg
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited