widgets/bar_chart library
Classes
- ChartData
- Represents a single data point in a chart.
- ChartSeriesData
- Represents a series of data points in a chart, with an assigned color.
- TBarChart
-
A widget that displays a bar chart using
SfCartesianChart. - TGroupBarChart
- A grouped bar chart widget that displays multiple series of data.