TBarChart class

A widget that displays a bar chart using SfCartesianChart.

This widget supports horizontal and vertical bar charts, optional legends, and an additional options button.

Inheritance

Constructors

TBarChart({Key? key, required String title, required List<ChartData> data, VoidCallback? optionTap, bool showLegends = true, bool showOption = true, Axis direction = Axis.horizontal, double? height = 300, Color? barColor})
Creates a TBarChart widget.
const

Properties

barColor Color?
The color of the bars in the chart.
final
data List<ChartData>
The data to be displayed in the chart.
final
direction Axis
The direction of the bar chart, either Axis.horizontal or Axis.vertical.
final
hashCode int
The hash code for this object.
no setterinherited
height double?
The height of the chart container.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
optionTap VoidCallback?
Callback function triggered when the options button is tapped.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showLegends bool
Determines whether to show legends below the chart.
final
showOption bool
Determines whether to show the options button.
final
title String
The title of the bar chart.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited