TBottomNavigationItem class

Constructors

TBottomNavigationItem({required Widget screen, required Widget activeIcon, Widget? inactiveIcon, required String title, Color? activeForegroundColor, Color? inactiveForegroundColor})

Properties

activeForegroundColor Color?
final
activeIcon Widget
final
hashCode int
The hash code for this object.
no setterinherited
inactiveForegroundColor Color?
final
inactiveIcon Widget?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screen Widget
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPersistentTabConfig(BuildContext context) → PersistentTabConfig
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited