TNavbarStyle class

Constructors

TNavbarStyle()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fixed3(BuildContext context, NavBarConfig navBarConfig, Color? backgroundColor) Widget
fixed4(BuildContext context, NavBarConfig navBarConfig, Color? backgroundColor) Widget
fixed5(BuildContext context, NavBarConfig navBarConfig, Color? activeColor, Color? backgroundColor) Widget
floating3(BuildContext context, NavBarConfig navBarConfig, Color? activeColor, Color? backgroundColor) Widget
floating4(BuildContext context, NavBarConfig navBarConfig, Color? activeColor, Color? backgroundColor) Widget
floating5(BuildContext context, NavBarConfig navBarConfig, Color? activeColor, Color? backgroundColor) Widget
style3(BuildContext context, NavBarConfig navBarConfig, Color? backgroundColor) Widget