TButtonDestructive class

Inheritance

Constructors

TButtonDestructive({Key? key, required String? text, required VoidCallback? onPressed, VoidCallback? onLongPress, Duration? longPressDuration, Color? backgroundColor, Color? onPressedBackgroundColor, Color? loadingColor, double borderRadius = 8, TextStyle? textStyle, Widget? suffixIcon, Widget? prefixIcon, bool loading = false, TButtonLoadingPosition loadingPosition = TButtonLoadingPosition.leading, double iconSpacing = 10, bool spaceBetween = false, Widget? child, EdgeInsetsGeometry? padding = const EdgeInsets.only(top: 10, bottom: 10, left: 12, right: 12), bool centerContent = true, Size minimumSize = const Size(double.infinity, 48), Size maximumSize = const Size(double.infinity, 48), double minFontSize = 12.0})
const
TButtonDestructive.icon({Key? key, required Widget icon, required VoidCallback? onPressed, VoidCallback? onLongPress, Duration? longPressDuration, Color? backgroundColor, Color? onPressedBackgroundColor, Color? loadingColor, double borderRadius = 8, TextStyle? textStyle, bool loading = false, TButtonLoadingPosition loadingPosition = TButtonLoadingPosition.leading, double iconSpacing = 10, bool spaceBetween = false, bool centerContent = true, Size minimumSize = const Size(48, 48), Size maximumSize = const Size(48, 48), double minFontSize = 12.0, EdgeInsetsGeometry? padding = const EdgeInsets.only(top: 10, bottom: 10, left: 12, right: 12)})
const

Properties

backgroundColor → Color?
final
borderRadius → double
final
centerContent → bool
final
child → Widget?
final
hashCode → int
The hash code for this object.
no setterinherited
iconSpacing → double
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loading → bool
final
loadingColor → Color?
final
loadingPosition → TButtonLoadingPosition
final
longPressDuration → Duration?
final
maximumSize → Size
final
minFontSize → double
final
minimumSize → Size
final
onLongPress → VoidCallback?
final
onPressed → VoidCallback?
final
onPressedBackgroundColor → Color?
final
padding → EdgeInsetsGeometry?
final
prefixIcon → Widget?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spaceBetween → bool
final
suffixIcon → Widget?
final
text → String?
final
textStyle → TextStyle?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<TButtonDestructive>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited