EventData class

Constructors

EventData({required DateTime date, required String title, String? description, DateTime? startTime, DateTime? endTime})

Properties

date DateTime
final
description String?
final
endTime DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime DateTime?
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited