ChartData class

Represents a single data point in a chart.

Constructors

ChartData(String label, double value)
Creates a ChartData instance with the given label and value.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
label String
The label or category of the data point.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double
The numerical value of the data point.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited