ChartSeriesData class

Represents a series of data points in a chart, with an assigned color.

Constructors

ChartSeriesData({required String label, required List<ChartData> data, required Color color})
Creates a ChartSeriesData instance with the given label, data, and color.
const

Properties

color Color
The color representing this series in the chart.
final
data List<ChartData>
The list of data points associated with this series.
final
hashCode int
The hash code for this object.
no setterinherited
label String
The label for the series.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited