TGroupBarChart class
A grouped bar chart widget that displays multiple series of data.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- TGroupBarChart
Constructors
-
TGroupBarChart({Key? key, required String title, required List<
ChartSeriesData> seriesList, VoidCallback? optionTap, bool showLegends = true, bool showOption = true, Axis direction = Axis.horizontal, double height = 300}) -
Creates a grouped bar chart widget.
const
Properties
- direction → Axis
-
The orientation of the chart bars (horizontal or vertical).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
The height of the chart.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- optionTap → VoidCallback?
-
Callback function triggered when the options button is tapped.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
seriesList
→ List<
ChartSeriesData> -
A list of series data to be displayed in the chart.
final
- showLegends → bool
-
Whether to display legends below the chart.
final
- showOption → bool
-
Whether to show the options button in the top-right corner.
final
- title → String
-
The title of the chart.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited