THeader class

Inheritance
Implemented types

Constructors

THeader({Key? key, required String title, TextStyle? titleStyle, bool enableCenterTitle = false, List<Widget>? suffixAction, Color? backgroundColor, Color? iconColor, Color? bottomColor})
const
THeader.brand({Key? key, required Widget icon, List<Widget>? suffixAction, Color? backgroundColor, Color? bottomColor})
const
THeader.homepage({Key? key, required String title, TextStyle? titleStyle, String? subtitle, TextStyle? subtitleStyle, bool enableCenterTitle = false, Widget? leadingAvatar, List<Widget>? suffixAction, Color? backgroundColor, Widget? prefixAction, Color? bottomColor})
const
THeader.nested({Key? key, required String title, TextStyle? titleStyle, bool enableCenterTitle = false, List<Widget>? suffixAction, Color? backgroundColor, Widget? prefixAction, Color? iconColor, Color? bottomColor})
const
THeader.search({Key? key, Color? backgroundColor, String? hintText, dynamic onSubmitted(String)?, dynamic onChanged(String)?, Widget? prefixAction, Color? iconColor, Color? bottomColor})
const

Properties

backgroundColor Color?
final
bottomColor Color?
final
enableCenterTitle bool
final
hashCode int
The hash code for this object.
no setterinherited
headerType HeaderType
final
hintText String?
final
icon Widget
final
iconColor Color?
final
isBackButtonEnabled bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leadingAvatar Widget?
final
onChanged → dynamic Function(String)?
final
onSubmitted → dynamic Function(String)?
final
preferredSize Size
The size this widget would prefer if it were otherwise unconstrained.
no setteroverride
prefixAction Widget?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle String?
final
subtitleStyle TextStyle?
final
suffixAction List<Widget>?
final
title String
final
titleStyle TextStyle?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<THeader>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited