LegendLabel class
Represents a legend label for a chart.
A legend label consists of:
- A
labelrepresenting the name or category. - A
colorassociated with the label for visual representation in the chart.
Constructors
- LegendLabel({required String label, required Color color})
-
Creates a new instance of LegendLabel.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited