LineChartData class

Represents a single data point in a line chart.

This class is used to store the x-axis label, y-axis value, and the color associated with a specific data point in a line chart.

Constructors

LineChartData({required String x, required double y, required Color color})
Creates a LineChartData instance.

Properties

color Color
The color associated with this data point.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x String
The label or category for the x-axis.
final
y double
The numerical value for the y-axis.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited