TTextField class

Inheritance

Constructors

TTextField({Key? key, String? labelText, required String hintText, required TextEditingController controller, required ValueChanged<String> onChange, ValueChanged<String>? onSubmitted, bool enableInstantDelete = false, int? maxLines = 1, int minLines = 1, TextInputType textInputType = TextInputType.text, Widget? leading, bool? enabled, bool readOnly = false, Color? borderColor, Color? focusedBorderColor, Widget? actionWidget, Color? hintColor, bool? autoFocus, FocusNode? focusNode, String? errorMessage, String? description, List<TextInputFormatter>? inputFormatter, double? height, Color? backgroundColor, String? helperText, VoidCallback? onEditingComplete, bool obscureText = false, String? counterText, Widget? passwordVisibilityIcon, Widget? passwordVisibilityOffIcon, bool showPasswordToggle = true, Widget? emailIcon, bool showEmailIcon = true, VoidCallback? onLeadingPressed, VoidCallback? onActionPressed})
const
TTextField.email({Key? key, String? labelText, required String hintText, required TextEditingController controller, required ValueChanged<String> onChange, ValueChanged<String>? onSubmitted, bool enableInstantDelete = false, int? maxLines = 1, int minLines = 1, bool? enabled, bool readOnly = false, Color? borderColor, Color? focusedBorderColor, Widget? actionWidget, Color? hintColor, bool? autoFocus, FocusNode? focusNode, String? errorMessage, String? description, List<TextInputFormatter>? inputFormatter, double? height, Color? backgroundColor, String? helperText, VoidCallback? onEditingComplete, String? counterText, TextInputType textInputType = TextInputType.emailAddress, Widget? leading, bool obscureText = false, Widget? passwordVisibilityIcon, Widget? passwordVisibilityOffIcon, bool showPasswordToggle = true, Widget? emailIcon, bool showEmailIcon = true, VoidCallback? onLeadingPressed, VoidCallback? onActionPressed})
const
TTextField.multiline({Key? key, String? labelText, required String hintText, required TextEditingController controller, required ValueChanged<String> onChange, ValueChanged<String>? onSubmitted, bool enableInstantDelete = false, int? maxLines, int minLines = 4, TextInputType textInputType = TextInputType.multiline, Widget? leading, bool? enabled, bool readOnly = false, Color? borderColor, Color? focusedBorderColor, Widget? actionWidget, Color? hintColor, bool? autoFocus, FocusNode? focusNode, String? errorMessage, String? description, List<TextInputFormatter>? inputFormatter, double? height, Color? backgroundColor, String? helperText, VoidCallback? onEditingComplete, bool obscureText = false, String? counterText, Widget? passwordVisibilityIcon, Widget? passwordVisibilityOffIcon, bool showPasswordToggle = true, Widget? emailIcon, bool showEmailIcon = true, VoidCallback? onLeadingPressed, VoidCallback? onActionPressed})
const
TTextField.password({Key? key, String? labelText, required String hintText, required TextEditingController controller, required ValueChanged<String> onChange, ValueChanged<String>? onSubmitted, bool enableInstantDelete = false, int? maxLines = 1, int minLines = 1, TextInputType textInputType = TextInputType.text, Widget? leading, bool? enabled, bool readOnly = false, Color? borderColor, Color? focusedBorderColor, Widget? actionWidget, Color? hintColor, bool? autoFocus, FocusNode? focusNode, String? errorMessage, String? description, List<TextInputFormatter>? inputFormatter, double? height, Color? backgroundColor, String? helperText, VoidCallback? onEditingComplete, bool obscureText = true, String? counterText, Widget? passwordVisibilityIcon, Widget? passwordVisibilityOffIcon, bool showPasswordToggle = true, Widget? emailIcon, bool showEmailIcon = true, VoidCallback? onLeadingPressed, VoidCallback? onActionPressed})
const

Properties

actionWidget Widget?
final
autoFocus bool?
final
backgroundColor Color?
final
borderColor Color?
final
controller TextEditingController
final
counterText String?
final
description String?
final
emailIcon Widget?
final
enabled bool?
final
enableInstantDelete bool
final
errorMessage String?
final
focusedBorderColor Color?
final
focusNode FocusNode?
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
helperText String?
final
hintColor Color?
final
hintText String
final
inputFormatter List<TextInputFormatter>?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelText String?
final
leading Widget?
final
maxLines int?
final
minLines int
final
obscureText bool
final
onActionPressed VoidCallback?
final
onChange ValueChanged<String>
final
onEditingComplete VoidCallback?
final
onLeadingPressed VoidCallback?
final
onSubmitted ValueChanged<String>?
final
passwordVisibilityIcon Widget?
final
passwordVisibilityOffIcon Widget?
final
readOnly bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showEmailIcon bool
final
showPasswordToggle bool
final
textInputType TextInputType
final
type TextFieldType
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() TTextFieldState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited