TTheme class

Constructors

TTheme({required Color primary, required Color primaryForeground, required Color primaryPressed, required Color secondary, required Color secondaryForeground, required Color secondaryPressed, required Color accent, required Color accentForeground, required Color destructive, required Color destructiveForeground, required Color destructivePressed, required Color warning, required Color warningForeground, required Color warningPressed, required Color success, required Color successForeground, required Color successPressed, required Color info, required Color infoForeground, required Color ring, required Color active, required Color background, required Color foreground, required Color muted, required Color mutedForeground, required Color card, required Color cardForeground, required Color popover, required Color popoverForeground, required Color border, required Color input, String? fontFamily = FontFamily.inter})
Private constructor for singleton instances
const
TTheme.dark()
factory
TTheme.light()
Use Predefined Instances Instead of New Objects
factory

Properties

accent Color
final
accentForeground Color
final
active Color
final
background Color
final
border Color
final
card Color
final
cardForeground Color
final
destructive Color
final
destructiveForeground Color
final
destructivePressed Color
final
fontFamily String?
final
foreground Color
final
hashCode int
The hash code for this object.
no setteroverride
info Color
final
infoForeground Color
final
input Color
final
muted Color
final
mutedForeground Color
final
popover Color
final
popoverForeground Color
final
primary Color
final
primaryForeground Color
final
primaryPressed Color
final
ring Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondary Color
final
secondaryForeground Color
final
secondaryPressed Color
final
success Color
final
successForeground Color
final
successPressed Color
final
themeData ThemeData
Convert TTheme to ThemeData with Correct Brightness
no setter
warning Color
final
warningForeground Color
final
warningPressed Color
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
Override Equality for Value Comparison
override

Static Properties

darkTheme TTheme
final
lightTheme TTheme
Predefined Singleton Instances
final