TTile<T> class
- Inheritance
- Available extensions
Constructors
-
TTile({Key? key, required String title, TextStyle? titleStyle, TextStyle? subtitleStyle, Color? backgroundColor, Color? disableBackgroundColor, Color? borderColor, BorderRadius? borderRadius, Color? textColor, bool? enable = true, String? subtitle, String? detail, Widget? prefixIcon, Widget? suffixIcon, EdgeInsets? padding, T? value, T? groupValue, ValueChanged<
T> ? onChanged, bool showRadio = false, VoidCallback? onPress}) -
const
Properties
- backgroundColor → Color?
-
final
- borderColor → Color?
-
final
- borderRadius → BorderRadius?
-
final
- detail → String?
-
final
- disableBackgroundColor → Color?
-
final
- enable → bool?
-
final
- groupValue → T?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onChanged
→ ValueChanged<
T> ? -
final
- onPress → VoidCallback?
-
final
- padding → EdgeInsets?
-
final
- prefixIcon → Widget?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showRadio → bool
-
final
- subtitle → String?
-
final
- subtitleStyle → TextStyle?
-
final
- suffixIcon → Widget?
-
final
- textColor → Color?
-
final
- title → String
-
final
- titleStyle → TextStyle?
-
final
- value → T?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
copyWith(
{String? title, TextStyle? titleStyle, Color? backgroundColor, Color? borderColor, BorderRadius? borderRadius, Color? textColor, bool? enable, String? subtitle, TextStyle? subtitleStyle, String? detail, Widget? prefixIcon, Widget? suffixIcon, EdgeInsets? padding, bool? showRadio, T? value, T? groupValue, ValueChanged< T?> ? onChanged}) → TTile<T> -
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited