widgets/avatar library
Classes
- TAvatar
- A customizable avatar widget that supports images, icons, text, and badges.
Enums
- AvatarShape
- Defines the shape of the avatar.
- AvatarSize
- Defines predefined sizes for the avatar.
- AvatarType
- Defines the type of avatar, which affects additional indicators.