TBottomNavigationHelper class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getCurrentIndex({BuildContext? context})
→ int
-
Get the current tab index
-
jumpToTab(int index, BuildContext? context)
→ void
-
Jump to a specific tab index
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
popScreen(BuildContext context)
→ void
-
Pop the current route
-
pushNewScreen<T extends Object?>(BuildContext context, {required Widget screen, bool withNavBar = false, PageTransitionAnimation pageTransitionAnimation = PageTransitionAnimation.platform, RouteSettings? settings})
→ Future<T?>
-
Pushes a new screen with transition, optionally with nav bar
-
pushNewScreenWithNavBar<T>(BuildContext context, Route<T> route)
→ Future<T?>
-
Push a raw route with nav bar
-
pushNewScreenWithoutNavBar<T>(BuildContext context, Route<T> route)
→ Future<T?>
-
Push a raw route without nav bar
-
pushReplacementWithNavBar<T extends Object?, TO extends Object?>(BuildContext context, Route<T> route, {TO? result})
→ Future<T?>
-
Replace current route with one with nav bar
-
pushReplacementWithoutNavBar<T extends Object?, TO extends Object?>(BuildContext context, Route<T> route, {TO? result})
→ Future<T?>
-
Replace current route with one without nav bar
-
pushScreenWithNavBar<T>(BuildContext context, Widget screen)
→ Future<T?>
-
Push a screen with nav bar, using built-in animation
-
pushScreenWithoutNavBar<T>(BuildContext context, Widget screen)
→ Future<T?>
-
Push a screen without nav bar, using built-in animation
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
setController(PersistentTabController controller)
→ void
-