LegendLabel class

Represents a legend label for a chart.

A legend label consists of:

  • A label representing the name or category.
  • A color associated with the label for visual representation in the chart.

Constructors

LegendLabel({required String label, required Color color})
Creates a new instance of LegendLabel.
const

Properties

color Color
The color associated with this legend item.
final
hashCode int
The hash code for this object.
no setterinherited
label String
The name or category of the legend item.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited