PieChartData constructor
const
PieChartData({})
Creates a new instance of PieChartData.
label: The name or category of the pie chart segment.value: The numerical value representing the size of the segment.color: The color used for the segment in the chart.
Implementation
const PieChartData({
required this.label,
this.labelColor,
required this.value,
this.valueColor,
required this.color,
});